Remove rocshmem_timer function
This commit is contained in:
@@ -638,12 +638,6 @@ __device__ int rocshmem_my_pe() {
|
||||
return get_internal_ctx(ROCSHMEM_CTX_DEFAULT)->my_pe;
|
||||
}
|
||||
|
||||
__device__ uint64_t rocshmem_timer() {
|
||||
GPU_DPRINTF("Function: rocshmem_timer\n");
|
||||
|
||||
return __read_clock();
|
||||
}
|
||||
|
||||
template <typename T>
|
||||
__device__ T rocshmem_atomic_fetch_add(rocshmem_ctx_t ctx, T *dest, T val,
|
||||
int pe) {
|
||||
|
||||
+2
-2
@@ -141,10 +141,10 @@ class Stats {
|
||||
StatType stats[I] = {0};
|
||||
|
||||
public:
|
||||
__device__ uint64_t startTimer() const { return rocshmem_timer(); }
|
||||
__device__ uint64_t startTimer() const { return wall_clock64(); }
|
||||
|
||||
__device__ void endTimer(uint64_t start, int index) {
|
||||
incStat(index, rocshmem_timer() - start);
|
||||
incStat(index, wall_clock64() - start);
|
||||
}
|
||||
|
||||
__device__ void incStat(int index, int value = 1) {
|
||||
|
||||
Reference in New Issue
Block a user